#ifndef SUB_CALLING
# include <stdio.h>
# include "callbacks.h"
# include "pfunc.h"
# include "sfunc.h"
# include "mfunc.h"
# include "modem.h"
#endif

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <termios.h>


int open_modem(const char * serial, const char * lock)
{
 FILE * flock;
 int h_modem = -1;

 if ( !access(lock, F_OK) )
  show_error_msg("ATTENZIONE: Il modem risulta impegnato: elimina il file /var/lock/LCK..modem");
 else if ( !access(serial, F_OK | W_OK | R_OK) )
 {
  g_print("\nModem is available... try to open");

  flock = fopen(lock, "w");
  if( flock != NULL )
  {
   fprintf(flock,"%d", (int)getpid() );
   fclose(flock);

   h_modem = openmodem(serial);
   if( h_modem < -1 )
   {
    show_error_msg("ERRORE: non posso aprire il modem in lettura/scrittura: controlla i permessi del device /dev/modem");
    perror(serial);
   }
   else
    g_print("\nModem open in read/write mode");

  }
  else
   show_error_msg("ERRORE: non posso bloccare il modem scrivendo sul file /var/lock/LCK..modem");
 }
 else
  show_error_msg("ERRORE: nessun modem trovato");

 return h_modem;
}


/* baudrate settings are defined in <asm/termbits.h>, which is included by <termios.h> */
#define BAUDRATE B38400
#define MY_O_CANON 35387

int openmodem(const char * MODEMDEVICE)
{
 int fd;
 struct termios options;

 /* Open modem device for reading and writing and not as controlling tty
    because we don't want to get killed if linenoise sends CTRL-C. */
 fd = open(MODEMDEVICE, O_RDWR | O_NOCTTY | O_NDELAY );
 if (fd < 0)
 {
  perror(MODEMDEVICE);
  return -1;
 }
 else
 {
  /*tcflush(fd, TCIOFLUSH);*/
  fcntl(fd, F_SETFL, 0);

  /* get the current options */
  tcgetattr(fd, &options);

  /* set raw input, 1 second timeout */
  options.c_cflag     |= (CLOCAL | CREAD);
  options.c_lflag     &= ~(ICANON | ECHO | ECHOE | ISIG);
  options.c_oflag     &= ~OPOST;
  options.c_cc[VMIN]  = 0;
  options.c_cc[VTIME] = 10;

  /* set the options */
  tcsetattr(fd, TCSANOW, &options);
 }

 return fd;
}


void send_modem(int fd_serial, const char * text)
{
 int i = 0;

 while(text[i])
 {
  g_print("%c",text[i]);
  write(fd_serial, &text[i], 1);
  i++;
 }
}
