
#ifdef da_convertire
/**
 * stf_open_for_write:
 * @context: commandcontext
 * @filename: file to open
 *
 * Opens a file
 *
 * Return value: NULL on error or a pointer to a FILE struct on success.
 **/
static FILE *
stf_open_for_write (IOContext *context, const char *filename)
{
	FILE *f = gnumeric_fopen (context, filename, "w");

	if (!f)
		return NULL;

	setvbuf (f, NULL, _IOFBF, PAGE_SIZE);

	return f;
}
#endif

#ifdef nonpiuqua 
/**
 * stf_write_func:
 * @string: data to write
 * @data: file to write too
 *
 * Callback routine which writes to a file
 *
 * Return value: TRUE on successful write, FALSE otherwise
 **/
static gboolean
stf_write_func (const char *string, FILE *f)
{
	if (fputs (string, f) >= 0)
		return TRUE;
	else
		return FALSE;
}
#endif

#ifdef nonserve
/**
 * stf_write_workbook
 * @fs       : file saver
 * @context  : command context
 * @book     : workbook
 * @filename : file to read from+convert
 *
 * Main routine, handles exporting a file including all dialog mumbo-jumbo
 *
 * returns : TRUE on success or FALSE otherwise
 **/
static gboolean
stf_write_workbook (FileSaver const *fs, IOContext *context, WorkbookView *wb_view, const char *filename)
stf_write_workbook (const char *filename)
{
	StfE_Result_t *result = NULL;

	g_return_val_if_fail (context != NULL, FALSE);
	g_return_val_if_fail (wb_view != NULL, FALSE);
	g_return_val_if_fail (filename != NULL, FALSE);

	if (IS_WORKBOOK_CONTROL_GUI (context->impl))
		result = stf_export_dialog (WORKBOOK_CONTROL_GUI (context->impl),
					    wb_view_workbook (wb_view));

	if (result != NULL) {
		FILE *f = stf_open_for_write (context, filename);

		if (!f)
			return FALSE;

		stf_export_options_set_write_callback (result->export_options,
						       (StfEWriteFunc) stf_write_func, (gpointer) f);
		fclose (f);

		if (stf_export (result->export_options) == FALSE) {

			gnumeric_error_read (COMMAND_CONTEXT (context),
					     _("Error while trying to write csv file"));
			stf_export_dialog_result_free (result);
			return FALSE;
		}

		stf_export_dialog_result_free (result);

		return TRUE;
	} else
		return FALSE;
}
/**
 * stf_init
 *
 * Registers the file format
 *
 * returns : nothing
 **/
void
stf_init (void)
{
	const char *desc;

	desc = _("Text File import");
	file_format_register_open (1, desc, NULL, stf_read_workbook);

	desc = _("Text File Export (*.csv)");
	file_format_register_save ("csv", desc, FILE_FL_MANUAL,
	                           stf_write_workbook);
}
#endif
